@@ -1,5 +1,5 @@
 from .app import Terminwind
 
 
-def main():
+def run():
     Terminwind.run(title="Terminwind")
